LIBRARY     BETEST.EXE

EXPORTS
    @Attack$qqsp16InteractionParam @1   ; Attack(InteractionParam*) __stdcall
    @Character@$bctr$qqs5_Core     @2   ; Character::Character(_Core) __stdcall
    @Character@$bctr$qqsv          @3   ; Character::Character() __stdcall
    @Character@$bdtr$qqsv          @4   ; Character::~Character() __stdcall
    @Character@AddItem$qqsp13InventoryItem @5   ; Character::AddItem(InventoryItem*) __stdcall
    @Character@ClearInventory$qqsv @6   ; Character::ClearInventory() __stdcall
    @Character@EnumInventory$qqsv  @7   ; Character::EnumInventory() __stdcall
    @Character@FillSaveBuffer$qqspuc @8   ; Character::FillSaveBuffer(unsigned char*) __stdcall
    @Character@GetItem$qqsp10ItemScorespp13InventoryItem @9   ; Character::GetItem(ItemScores*,InventoryItem**) __stdcall
    @Character@GetItem$qqsuspp13InventoryItem @10  ; Character::GetItem(unsigned short,InventoryItem**) __stdcall
    @Character@Init$qqs5_Core      @11  ; Character::Init(_Core) __stdcall
    @Character@InvListToArray$qqsppp10ItemScores @12  ; Character::InvListToArray(ItemScores***) __stdcall
    @Character@ItemsQty$qqsv       @13  ; Character::ItemsQty() __stdcall
    @Character@RestoreFromBufferStep1$qqspucus @14  ; Character::RestoreFromBufferStep1(unsigned char*,unsigned short) __stdcall
    @Character@RestoreFromBufferStep2$qqspucuspp5Agentusppp10ItemScorespus @15  ; Character::RestoreFromBufferStep2(unsigned char*,unsigned short,Agent**,unsigned short,ItemScores***,unsigned short*) __stdcall
    @Character@SetBEScores$qqs5_Core @16  ; Character::SetBEScores(_Core) __stdcall
    @Character@cAutoNumber         @17  ; Character::cAutoNumber
    @Classes@TComponent@UpdateRegistry$qqr4boolx17System@AnsiStringxt2 @18  ; Classes::TComponent::UpdateRegistry(bool,const System::AnsiString,const System::AnsiString) __fastcall
    @Classes@TComponent@UpdateRegistry$qqr4boolx17System@AnsiStringxt2 @19  ; Classes::TComponent::UpdateRegistry(bool,const System::AnsiString,const System::AnsiString) __fastcall
    @Classes@TComponent@UpdateRegistry$qqr4boolx17System@AnsiStringxt2 @20  ; Classes::TComponent::UpdateRegistry(bool,const System::AnsiString,const System::AnsiString) __fastcall
    @Classes@TComponent@UpdateRegistry$qqr4boolx17System@AnsiStringxt2 @21  ; Classes::TComponent::UpdateRegistry(bool,const System::AnsiString,const System::AnsiString) __fastcall
    @Classes@TComponent@UpdateRegistry$qqr4boolx17System@AnsiStringxt2 @22  ; Classes::TComponent::UpdateRegistry(bool,const System::AnsiString,const System::AnsiString) __fastcall
    @Classes@TComponent@UpdateRegistry$qqr4boolx17System@AnsiStringxt2 @23  ; Classes::TComponent::UpdateRegistry(bool,const System::AnsiString,const System::AnsiString) __fastcall
    @Deal$qqsp16InteractionParam   @24  ; Deal(InteractionParam*) __stdcall
    @Forms@TForm@$bctr$qqrp18Classes@TComponent @25  ; Forms::TForm::TForm(Classes::TComponent*) __fastcall
    @Forms@TForm@$bctr$qqrp18Classes@TComponent @26  ; Forms::TForm::TForm(Classes::TComponent*) __fastcall
    @Forms@TForm@$bctr$qqrp18Classes@TComponent @27  ; Forms::TForm::TForm(Classes::TComponent*) __fastcall
    @Forms@TForm@$bctr$qqrp18Classes@TComponent @28  ; Forms::TForm::TForm(Classes::TComponent*) __fastcall
    @Forms@TForm@$bctr$qqrp18Classes@TComponent @29  ; Forms::TForm::TForm(Classes::TComponent*) __fastcall
    @Forms@TForm@$bctr$qqrp18Classes@TComponent @30  ; Forms::TForm::TForm(Classes::TComponent*) __fastcall
    @Forms@TForm@$bdtr$qqrv        @31  ; Forms::TForm::~TForm() __fastcall
    @Forms@TForm@$bdtr$qqrv        @32  ; Forms::TForm::~TForm() __fastcall
    @Forms@TForm@$bdtr$qqrv        @33  ; Forms::TForm::~TForm() __fastcall
    @Forms@TForm@$bdtr$qqrv        @34  ; Forms::TForm::~TForm() __fastcall
    @Forms@TForm@$bdtr$qqrv        @35  ; Forms::TForm::~TForm() __fastcall
    @Forms@TForm@$bdtr$qqrv        @36  ; Forms::TForm::~TForm() __fastcall
    @GatherGang$qqsp16InteractionParam @37  ; GatherGang(InteractionParam*) __stdcall
    @GiveItem$qqsp16InteractionParam @38  ; GiveItem(InteractionParam*) __stdcall
    @GroupNonLethalAttack$qqsp16InteractionParam @39  ; GroupNonLethalAttack(InteractionParam*) __stdcall
    @Inifiles@TCustomIniFile@$bdtr$qqrv @40  ; Inifiles::TCustomIniFile::~TCustomIniFile() __fastcall
    @Inifiles@TIniFile@$bctr$qqrx17System@AnsiString @41  ; Inifiles::TIniFile::TIniFile(const System::AnsiString) __fastcall
    @Inifiles@TIniFile@$bdtr$qqrv  @42  ; Inifiles::TIniFile::~TIniFile() __fastcall
    @InventoryItem@$bctr$qqsv      @43  ; InventoryItem::InventoryItem() __stdcall
    @InventoryItem@$bdtr$qqsv      @44  ; InventoryItem::~InventoryItem() __stdcall
    @InventoryItem@SetBEScores$qqszczczczczczczc @45  ; InventoryItem::SetBEScores(signed char,signed char,signed char,signed char,signed char,signed char,signed char) __stdcall
    @Leave$qqsp16InteractionParam  @46  ; Leave(InteractionParam*) __stdcall
    @NonLethalAttack$qqsp16InteractionParam @47  ; NonLethalAttack(InteractionParam*) __stdcall
    @Request$qqsp16InteractionParam @48  ; Request(InteractionParam*) __stdcall
    @Statement$qqsp16InteractionParam @49  ; Statement(InteractionParam*) __stdcall
    @Steal$qqsp16InteractionParam  @50  ; Steal(InteractionParam*) __stdcall
    @System@%DelphiInterface$t14Forms@IOleForm%@$bdtr$qqrv @51  ; System::DelphiInterface<Forms::IOleForm>::~IOleForm>() __fastcall
    @System@%DelphiInterface$t14Forms@IOleForm%@$bdtr$qqrv @52  ; System::DelphiInterface<Forms::IOleForm>::~IOleForm>() __fastcall
    @System@%DelphiInterface$t14Forms@IOleForm%@$bdtr$qqrv @53  ; System::DelphiInterface<Forms::IOleForm>::~IOleForm>() __fastcall
    @System@%DelphiInterface$t14Forms@IOleForm%@$bdtr$qqrv @54  ; System::DelphiInterface<Forms::IOleForm>::~IOleForm>() __fastcall
    @System@%DelphiInterface$t14Forms@IOleForm%@$bdtr$qqrv @55  ; System::DelphiInterface<Forms::IOleForm>::~IOleForm>() __fastcall
    @System@%DelphiInterface$t14Forms@IOleForm%@$bdtr$qqrv @56  ; System::DelphiInterface<Forms::IOleForm>::~IOleForm>() __fastcall
    @System@%DelphiInterface$t8IUnknown%@$bdtr$qqrv @57  ; System::DelphiInterface<IUnknown>::~DelphiInterface<IUnknown>() __fastcall
    @System@%DelphiInterface$t8IUnknown%@$bdtr$qqrv @58  ; System::DelphiInterface<IUnknown>::~DelphiInterface<IUnknown>() __fastcall
    @System@%DelphiInterface$t8IUnknown%@$bdtr$qqrv @59  ; System::DelphiInterface<IUnknown>::~DelphiInterface<IUnknown>() __fastcall
    @System@%DelphiInterface$t8IUnknown%@$bdtr$qqrv @60  ; System::DelphiInterface<IUnknown>::~DelphiInterface<IUnknown>() __fastcall
    @System@%DelphiInterface$t8IUnknown%@$bdtr$qqrv @61  ; System::DelphiInterface<IUnknown>::~DelphiInterface<IUnknown>() __fastcall
    @System@%DelphiInterface$t8IUnknown%@$bdtr$qqrv @62  ; System::DelphiInterface<IUnknown>::~DelphiInterface<IUnknown>() __fastcall
    @TakeItem$qqsp16InteractionParam @63  ; TakeItem(InteractionParam*) __stdcall
    @Tease$qqsp16InteractionParam  @64  ; Tease(InteractionParam*) __stdcall
    @Threat$qqsp16InteractionParam @65  ; Threat(InteractionParam*) __stdcall
    __GetExceptDLLinfo             @66  
    ___CPPdebugHook                @67  
